/*
* This is the mikromedia board TFT graphics driver
*/


#include "minisub_driver.h"
#include "built_in.h"  
          
//Note: MikroC's "built_in.h" provides the Hi and Lo functions


// Set index
void Set_Index(unsigned short index) {
        TFT_RS = 0;
        Lo(LATA) = index;
        TFT_WR = 0;
        TFT_WR = 1;
}

// Write command
void Write_Command(unsigned short cmd) {
        TFT_RS = 1;
        Lo(LATA) = cmd;
        TFT_WR = 0;
        TFT_WR = 1;
}

// Write data
void Write_Data(unsigned int _data) {
        TFT_RS = 1;
        Lo(LATE) = Hi(_data);
        Lo(LATA) = Lo(_data);
        TFT_WR = 0;
        TFT_WR = 1;
}


void Init_MCU() {
        //TRISE = 0;
        TFT_DataPort_Direction = 0;
        CLKDIVbits.PLLPRE = 0;      // PLLPRE<4:0> = 0  ->  N1 = 2    8MHz / 2 = 4MHz
                                    // (must be within 0.8 MHz to 8 MHz range)
        PLLFBD =   30;              // PLLDIV<8:0> = 30 ->  M = 32    4MHz * 32 = 128MHz
                                    // (must be within 100 MHz to 200 MHz range)
        CLKDIVbits.PLLPOST = 0;     // PLLPOST<1:0> = 0 ->  N2 = 2    128MHz / 2 = 64MHz
                                    // (must be within 12.5 MHz to 80 MHz range)
        Delay_ms(150);
        TFT_Set_Active(Set_Index,Write_Command,Write_Data);
        
        //Set up the MMB for a normal display orientation
        TFT_Init(320, 240);
        
        //Alternate MMB 'sideways' display orientation
        //TFT_Init(240, 320);
        
         UART2_Init(256000);               // Initialize UART module at 256000 baud
         UART_Set_Active(UART2_Read, UART2_Write, UART2_Data_Ready, UART2_Tx_Idle);
         Delay_ms(100);                  // Wait for UART module to stabilize

         //setup the default font
         TFT_Set_Font(TFT_defaultFont, CL_WHITE, FO_HORIZONTAL);
}